/* tai2tai64n -- Convert older TAI format timestamps to TAI64N
 * Copyright (C) 2000 Bruce Guenter <bruceg@em.ca>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#include <stdio.h>
#include "tai.h"

int main()
{
  char buf[4096];
  while(fgets(buf, 4096, stdin)) {
    const char* ptr = 0;
    tai* t = tai_decode(buf, &ptr);
    if(ptr) {
      char tmp[32];
      tai64n_encode(t, tmp);
      fputs(tmp, stdout);
      fputs(ptr, stdout);
    }
    else
      fputs(buf, stdout);
    fflush(stdout);
  }
  return 0;
}
